import { Controller, Get, Param, UseInterceptors } from '@nestjs/common';
import { ApiBearerAuth, ApiOperation, ApiTags } from '@nestjs/swagger';
import { ApiOkPaginatedResponse, ApiPaginationQuery, Paginate, type PaginateQuery } from 'nestjs-paginate';
import { SocioEntity } from '../../modules/database/connections/oceano';
import { AnagraficaService } from './anagrafica.service';
import { RequestLoggerInterceptor } from '../../modules/request-logging/request-logger.interceptor';

@UseInterceptors(RequestLoggerInterceptor)
@ApiBearerAuth()
@ApiTags('anagrafica')
@Controller('anagrafiche')
export class AnagraficaController {
  constructor(private anagraficaService: AnagraficaService) {}

  @Get()
  @ApiOperation({ summary: 'Find all Anagrafiche' })
  @ApiPaginationQuery(AnagraficaService.findPaginateConfig())
  @ApiOkPaginatedResponse(SocioEntity, AnagraficaService.findPaginateConfig())
  async getAnagrafiche(@Paginate() query: PaginateQuery) {
    return this.anagraficaService.getAnagrafiche(query);
  }

  @Get('id/:id')
  @ApiOperation({ summary: 'Get one Anagrafica by id' })
  async getOneAnagraficaById(@Param('id') id: string) {
    return this.anagraficaService.getOneAnagraficaById(id);
  }
}
