import { Injectable, Logger } from '@nestjs/common';
import { InjectRepository } from '@nestjs/typeorm';
import { paginate, PaginateConfig, PaginateQuery } from 'nestjs-paginate';
import { Repository } from 'typeorm';
import { SocioEntity } from '../../modules/database/connections/oceano';
import { OCEANO_DATASOURCE } from '../../modules/database/connections/oceano/database.constants';

@Injectable()
export class AnagraficaService {
  private readonly logger = new Logger(AnagraficaService.name);

  static readonly findPaginateConfig = (): PaginateConfig<SocioEntity> => ({
    relations: {},
    sortableColumns: ['codiceSocio', 'idNucleo', 'idPersona'],
    searchableColumns: [],
    defaultSortBy: [['codiceSocio', 'ASC']],
    defaultLimit: 50,
    maxLimit: -1,
    filterableColumns: {},
    relativePath: true,
    where: {
      codiceGruppo: '6',
    },
  });

  constructor(
    @InjectRepository(SocioEntity, OCEANO_DATASOURCE)
    private readonly sociRepository: Repository<SocioEntity>,
  ) {}

  async getAnagrafiche(query: PaginateQuery) {
    const config = AnagraficaService.findPaginateConfig();
    query.limit ??= -1;

    return await paginate(query, this.sociRepository, config);
  }

  async getOneAnagraficaById(idAnagrafica: string) {
    return await this.sociRepository.findOne({
      where: {
        ...AnagraficaService.findPaginateConfig().where,
        codiceSocio: idAnagrafica,
      },
    });
  }
}
