import { registerAs } from '@nestjs/config';
import { z } from 'zod';
import coerceRecordTypes from '../config/utils/coerce-record-types';

export const authSchema = z.object({
  accessToken: z.object({
    secret: z.string(),
    expTimeInSecs: z.number().finite().nonnegative(),
  }),
  refreshToken: z.object({
    secret: z.string(),
    expTimeInSecs: z.number().finite().nonnegative(),
  }),
});
export type AuthConfig = z.infer<typeof authSchema>;

export const authConfig = registerAs('auth', () => {
  const env = coerceRecordTypes(process.env);

  const config: AuthConfig = authSchema.strict().parse({
    accessToken: {
      secret: env['JWT_ACCESS_TOKEN_SECRET'],
      expTimeInSecs: env['JWT_ACCESS_TOKEN_EXPIRATION_TIME_IN_SECONDS'],
    },
    refreshToken: {
      secret: env['JWT_REFRESH_TOKEN_SECRET'],
      expTimeInSecs: env['JWT_REFRESH_TOKEN_EXPIRATION_TIME_IN_SECONDS'],
    },
  });
  return config;
});
