import { Module } from '@nestjs/common';
import { APP_GUARD, Reflector } from '@nestjs/core';
import { PassportModule } from '@nestjs/passport';
import { TypeOrmModule } from '@nestjs/typeorm';
import { AccountsEntity } from '../database/connections/ebitemp-api/entities';
import { AuthController } from './auth.controller';
import { AuthService } from './auth.service';
import { JwtAccessTokenAuthStrategy } from './strategies/jwt/jwt-access-token-auth.strategy';
import { JwtAccessTokenModule } from './strategies/jwt/jwt-access-token.module';
import { JwtAuthGuard } from './strategies/jwt/jwt-auth.guard';
import { JwtRefreshTokenAuthStrategy } from './strategies/jwt/jwt-refresh-token-auth.strategy';
import { JwtRefreshTokenModule } from './strategies/jwt/jwt-refresh-token.module';
import { UsersAuthModule } from './users/users.module';
import { EBITEMP_API_DATASOURCE } from '../database/connections/ebitemp-api/database.constants';

@Module({
  imports: [
    TypeOrmModule.forFeature([AccountsEntity], EBITEMP_API_DATASOURCE),
    JwtAccessTokenModule,
    JwtRefreshTokenModule,
    PassportModule,
    UsersAuthModule,
  ],
  controllers: [AuthController],
  providers: [
    {
      provide: APP_GUARD,
      useFactory: (reflector) => new JwtAuthGuard(reflector),
      inject: [Reflector],
    },
    AuthService,
    JwtAccessTokenAuthStrategy,
    JwtRefreshTokenAuthStrategy,
  ],
})
export class AppAuthModule {}
