import { Inject, Injectable, UnauthorizedException } from '@nestjs/common';
import { PassportStrategy } from '@nestjs/passport';
import { FastifyRequest } from 'fastify';
import { ClsService } from 'nestjs-cls';
import { ExtractJwt, Strategy } from 'passport-jwt';
import { AppClsStore } from '../../../cls/cls.interface';
import { type AuthConfig, authConfig } from '../../auth.config';
import { TokenPayload } from '../../constants/token-payload.interface';
import { UsersAuthService } from '../../users/users-auth.service';

@Injectable()
export class JwtAccessTokenAuthStrategy extends PassportStrategy(Strategy, 'jwt-access-token') {
  constructor(
    @Inject(authConfig.KEY) authConfig: AuthConfig,
    private readonly cls: ClsService<AppClsStore>,
    private readonly userAuthService: UsersAuthService,
  ) {
    super({
      jwtFromRequest: ExtractJwt.fromAuthHeaderAsBearerToken(),
      secretOrKey: authConfig.accessToken.secret,
      passReqToCallback: true,
    });
  }

  async validate(request: FastifyRequest, payload: TokenPayload) {
    const account = await this.userAuthService.getUserById(payload.sub);
    if (!account) throw new UnauthorizedException('Access Token Guard');
    this.cls.set('account', account);
    return account;
  }
}
