import { Module } from '@nestjs/common';
import { JwtService, JwtModule as NestJwtModule } from '@nestjs/jwt';
import { authConfig, AuthConfig } from '../../auth.config';
import { ConfigModule } from '@nestjs/config';

export const ACCESS_TOKEN_JWT_SERVICE = Symbol('ACCESS_TOKEN_JWT_SERVICE');
const accessTokenJwtProvider = {
  provide: ACCESS_TOKEN_JWT_SERVICE,
  useFactory: (jwtService: JwtService) => jwtService,
  inject: [JwtService],
};

@Module({
  imports: [
    ConfigModule.forFeature(authConfig),
    NestJwtModule.registerAsync({
      imports: [...authConfig.asProvider().imports],
      useFactory: async (authConfig: AuthConfig) => ({
        secret: authConfig.accessToken.secret,
        signOptions: {
          expiresIn: `${authConfig.accessToken.expTimeInSecs}s`,
        },
      }),
      inject: [authConfig.KEY],
    }),
  ],
  providers: [accessTokenJwtProvider],
  exports: [ConfigModule, accessTokenJwtProvider],
})
export class JwtAccessTokenModule {}
