import { applyDecorators, ExecutionContext, SetMetadata } from '@nestjs/common';
import { Reflector } from '@nestjs/core';
import { AuthGuard } from '@nestjs/passport';
import { OpenAPIObject } from '@nestjs/swagger';

export const IS_PUBLIC_KEY = 'isPublic';
export const Public = (keepSecurity: boolean = false) => {
  const decorators = [SetMetadata(IS_PUBLIC_KEY, true)];
  if (!keepSecurity) decorators.push(SetMetadata('swagger/apiSecurity', ['public']));
  return applyDecorators(...decorators);
};

export const patchPublicDecoratorSupport = (document: OpenAPIObject) => {
  Object.values(document.paths).forEach((path: any) => {
    Object.values(path).forEach((method: any) => {
      if (Array.isArray(method.security) && method.security.includes('public')) {
        method.security = [];
      }
    });
  });
  return document;
};

export class JwtAuthGuard extends AuthGuard('jwt-access-token') {
  constructor(private reflector: Reflector) {
    super();
  }

  canActivate(context: ExecutionContext) {
    const isPublic = this.reflector.getAllAndOverride<boolean>(IS_PUBLIC_KEY, [
      context.getHandler(),
      context.getClass(),
    ]);
    if (isPublic) {
      return true;
    }
    return super.canActivate(context);
  }
}
