import { Module } from '@nestjs/common';
import { ConfigModule } from '@nestjs/config';
import { JwtService, JwtModule as NestJwtModule } from '@nestjs/jwt';
import { authConfig, AuthConfig } from '../../auth.config';

export const REFRESH_TOKEN_JWT_SERVICE = Symbol('REFRESH_TOKEN_JWT_SERVICE');
const refreshTokenJwtProvider = {
  provide: REFRESH_TOKEN_JWT_SERVICE,
  useFactory: (jwtService: JwtService) => jwtService,
  inject: [JwtService],
};

@Module({
  imports: [
    ConfigModule.forFeature(authConfig),
    NestJwtModule.registerAsync({
      imports: [...authConfig.asProvider().imports],
      useFactory: async (authConfig: AuthConfig) => ({
        secret: authConfig.refreshToken.secret,
        signOptions: {
          expiresIn: `${authConfig.refreshToken.expTimeInSecs}s`,
        },
      }),
      inject: [authConfig.KEY],
    }),
  ],
  providers: [refreshTokenJwtProvider],
  exports: [ConfigModule, refreshTokenJwtProvider],
})
export class JwtRefreshTokenModule {}
