import { Module } from '@nestjs/common';
import { ConfigModule } from '@nestjs/config';
import { TypeOrmModule } from '@nestjs/typeorm';
import { DatabaseConfig } from '../../utils/database-config';
import { typeormTransactionalDataSourceFactory } from '../../utils/typeorm-data-source-factory';
import { typeormEntitiesFromImport } from '../../utils/typeorm-import-entities';
import { typeormModuleOptionsFactory } from '../../utils/typeorm-module-options-factory';
import { databaseConfig } from './database.config';
import { EBITEMP_API_DATASOURCE } from './database.constants';

@Module({
  imports: [
    ConfigModule.forFeature(databaseConfig),
    TypeOrmModule.forRootAsync({
      imports: databaseConfig.asProvider().imports,
      name: EBITEMP_API_DATASOURCE,
      dataSourceFactory: typeormTransactionalDataSourceFactory(EBITEMP_API_DATASOURCE),
      useFactory: async (dbConfig: DatabaseConfig) => {
        const config = await typeormModuleOptionsFactory(
          dbConfig,
          await typeormEntitiesFromImport(await import('./index.js')),
          EBITEMP_API_DATASOURCE,
        );
        return config;
      },
      inject: [databaseConfig.KEY],
    }),
  ],
  providers: [],
  exports: [TypeOrmModule],
})
export class EbitempApiDatabaseModule {}
