import { toZod } from 'tozod';
import { Column, Entity, Index, OneToMany } from 'typeorm';
import { z } from 'zod';
import { ProfiliEntity, ProfiliEntitySchema } from './profili.entity';

@Index('pk_accounts', ['id'], { unique: true })
@Entity('accounts')
export class AccountsEntity {
  @Column('int', { primary: true, name: 'id' })
  id!: number;

  @Column('varchar', { name: 'username', unique: true, length: 255 })
  username!: string;

  @Column('varchar', { name: 'password', nullable: true, length: 255 })
  password!: string | null;

  @Column('varchar', { name: 'nome', length: 255 })
  nome!: string;

  @Column('date', { name: 'data_creazione' })
  dataCreazione!: Date;

  @Column('date', { name: 'data_scadenza', nullable: true })
  dataScadenza!: Date | null;

  @Column('varchar', {
    name: 'ultimo_hash_refresh_token',
    nullable: true,
    length: 1024,
  })
  ultimoHashRefreshToken!: string | null;

  @OneToMany(() => ProfiliEntity, (profiliEntity) => profiliEntity.account)
  profili!: ProfiliEntity[];

  constructor(init?: Partial<AccountsEntity>) {
    Object.assign(this, init);
  }
}

export const AccountsEntitySchema: toZod<AccountsEntity> = z.late.object(() => ({
  id: z.number().finite(),
  username: z.string().nonempty(),
  password: z.string().nonempty().nullable(),
  nome: z.string().nonempty(),
  dataCreazione: z.date(),
  dataScadenza: z.date().nullable(),
  ultimoHashRefreshToken: z.string().nonempty().nullable(),
  profili: z.array(ProfiliEntitySchema),
}));
