import { Column, Entity, Index, JoinColumn, ManyToOne, PrimaryGeneratedColumn } from 'typeorm';
import { AccountsEntity } from './accounts.entity';
import { ApiEndpointEntity } from './api_endpoint.entity';

@Index('pk_api_endpoint_invocazioni', ['id'], { unique: true })
@Entity('api_endpoint_invocazioni')
export class ApiEndpointInvocazioniEntity {
  @PrimaryGeneratedColumn({ type: 'int', name: 'id' })
  id!: number;

  @Column('int', { name: 'id_account' })
  idAccount!: number;

  @Column('int', { name: 'id_endpoint' })
  idEndpoint!: number;

  @Column('datetime', { name: 'timestamp' })
  timestamp!: Date;

  @Column('varchar', { name: 'richiesta' })
  richiesta!: string;

  @Column('varchar', { name: 'risposta' })
  risposta!: string;

  @Column('bit', { name: 'flag_errore' })
  flagErrore!: boolean;

  @ManyToOne(() => ApiEndpointEntity, (apiEndpointEntity) => apiEndpointEntity.invocazioni)
  @JoinColumn([{ name: 'id_endpoint', referencedColumnName: 'id' }])
  endpoint!: ApiEndpointEntity;

  @ManyToOne(() => AccountsEntity)
  @JoinColumn([{ name: 'id_account', referencedColumnName: 'id' }])
  account!: AccountsEntity;

  constructor(init?: Partial<ApiEndpointInvocazioniEntity>) {
    Object.assign(this, init);
  }
}
