import { Column, Entity, Index, JoinColumn, ManyToOne } from 'typeorm';
import { AccountsEntity, AccountsEntitySchema } from './accounts.entity';
import { RuoliEntity, RuoliEntitySchema } from './ruoli.entity';
import { toZod } from 'tozod';
import { z } from 'zod';

@Index('pk_profili', ['id'], { unique: true })
@Entity('profili')
export class ProfiliEntity {
  @Column('int', { primary: true, name: 'id' })
  id!: number;

  @Column('int', { name: 'id_account', unique: true })
  idAccount!: number;

  @Column('int', { name: 'id_ruolo', unique: true })
  idRuolo!: number;

  @ManyToOne(() => AccountsEntity, (accountsEntity) => accountsEntity.profili)
  @JoinColumn([{ name: 'id_account', referencedColumnName: 'id' }])
  account!: AccountsEntity;

  @ManyToOne(() => RuoliEntity, (ruoliEntity) => ruoliEntity.profili)
  @JoinColumn([{ name: 'id_ruolo', referencedColumnName: 'id' }])
  ruolo!: RuoliEntity;

  constructor(init?: Partial<ProfiliEntity>) {
    Object.assign(this, init);
  }
}

export const ProfiliEntitySchema: toZod<ProfiliEntity> = z.late.object(() => ({
  id: z.number().finite(),
  idAccount: AccountsEntitySchema.shape.id,
  idRuolo: RuoliEntitySchema.shape.id,
  account: AccountsEntitySchema,
  ruolo: RuoliEntitySchema,
}));
