import { Column, Entity, Index, OneToMany } from 'typeorm';
import { ProfiliEntity, ProfiliEntitySchema } from './profili.entity';
import { toZod } from 'tozod';
import { z } from 'zod';

@Index('pk_ruoli', ['id'], { unique: true })
@Entity('ruoli')
export class RuoliEntity {
  @Column('int', { primary: true, name: 'id' })
  id!: number;

  @Column('varchar', { name: 'nome', unique: true, length: 255 })
  nome!: string;

  @Column('varchar', { name: 'descrizione', length: 255 })
  descrizione!: string;

  @OneToMany(() => ProfiliEntity, (profiliEntity) => profiliEntity.ruolo)
  profili!: ProfiliEntity[];

  constructor(init?: Partial<RuoliEntity>) {
    Object.assign(this, init);
  }
}

export const RuoliEntitySchema: toZod<RuoliEntity> = z.late.object(() => ({
  id: z.number().finite(),
  nome: z.string().nonempty(),
  descrizione: z.string().nonempty(),
  profili: z.array(ProfiliEntitySchema),
}));
