import { Column, Entity, Index, JoinColumn, ManyToOne, OneToMany } from 'typeorm';
import { ContrattoEntity } from './contratto.entity';
import { GruppoEntity } from './gruppo.entity';

@Index('PK_ent', ['codiceEnte'], { unique: true })
@Entity('ente')
export class EnteEntity {
  @Column('bigint', { primary: true, name: 'codiceEnte' })
  codiceEnte!: string;

  @Column('nvarchar', { name: 'ragioneSociale', nullable: true, length: 255 })
  ragioneSociale!: string | null;

  @Column('nvarchar', { name: 'partitaIva', nullable: true, length: 25 })
  partitaIva!: string | null;

  @Column('nvarchar', { name: 'codiceFiscale', nullable: true, length: 25 })
  codiceFiscale!: string | null;

  @Column('ntext', { name: 'noteEnte', nullable: true })
  noteEnte!: string | null;

  @Column('nvarchar', {
    name: 'codiceDivisioneEsolver',
    nullable: true,
    length: 25,
  })
  codiceDivisioneEsolver!: string | null;

  @Column('int', { name: 'enteAttivo', nullable: true })
  enteAttivo!: number | null;

  @Column('nvarchar', { name: 'indirizzoEnte', nullable: true, length: 80 })
  indirizzoEnte!: string | null;

  @Column('nvarchar', { name: 'numeroCivicoEnte', nullable: true, length: 80 })
  numeroCivicoEnte!: string | null;

  @Column('nvarchar', { name: 'capEnte', nullable: true, length: 10 })
  capEnte!: string | null;

  @Column('nvarchar', { name: 'localitaEnte', nullable: true, length: 80 })
  localitaEnte!: string | null;

  @Column('bigint', { name: 'utenteCreazione', nullable: true })
  utenteCreazione!: string | null;

  @Column('nvarchar', { name: 'dataCreazione', nullable: true, length: 10 })
  dataCreazione!: string | null;

  @Column('nvarchar', { name: 'oraCreazione', nullable: true, length: 8 })
  oraCreazione!: string | null;

  @Column('bigint', { name: 'utenteModifica', nullable: true })
  utenteModifica!: string | null;

  @Column('nvarchar', { name: 'dataModifica', nullable: true, length: 10 })
  dataModifica!: string | null;

  @Column('nvarchar', { name: 'oraModifica', nullable: true, length: 8 })
  oraModifica!: string | null;

  @Column('bigint', { name: 'codiceGruppo', nullable: true })
  codiceGruppo!: string | null;

  @Column('bigint', { name: 'statoEnte', nullable: true })
  statoEnte!: string | null;

  @Column('bigint', { name: 'provinciaEnte', nullable: true })
  provinciaEnte!: string | null;

  @Column('int', { name: 'inOsservazione', nullable: true })
  inOsservazione!: number | null;

  @Column('nvarchar', { name: 'sitoInternet', nullable: true, length: 255 })
  sitoInternet!: string | null;

  @ManyToOne(() => GruppoEntity, (gruppoEntity) => gruppoEntity.enti)
  gruppo!: ContrattoEntity;

  @OneToMany(() => ContrattoEntity, (contrattoEntity) => contrattoEntity.ente)
  contratti!: ContrattoEntity[];

  constructor(init?: Partial<EnteEntity>) {
    Object.assign(this, init);
  }
}
