import { Column, Entity, Index, JoinColumn, ManyToOne, OneToMany } from 'typeorm';
import { SocioFormeAssistenzaEntity } from './socioFormeAssistenza.entity';

@Index('PK_formeAssistenza', ['codiceFda'], { unique: true })
@Entity('formeAssistenza')
export class FormeAssistenzaEntity {
  @Column('bigint', { name: 'codiceGruppo' })
  codiceGruppo!: string;

  @Column('bigint', { primary: true, name: 'codiceFda' })
  codiceFda!: string;

  @Column('nvarchar', { name: 'descrizioneFda', nullable: true, length: 80 })
  descrizioneFda!: string | null;

  @Column('int', { name: 'attivaFda', nullable: true })
  attivaFda!: number | null;

  @Column('int', { name: 'fornituraTesserino', nullable: true })
  fornituraTesserino!: number | null;

  @Column('ntext', { name: 'noteFda', nullable: true })
  noteFda!: string | null;

  @Column('bigint', { name: 'utenteCreazione', nullable: true })
  utenteCreazione!: string | null;

  @Column('nvarchar', { name: 'dataCreazione', nullable: true, length: 10 })
  dataCreazione!: string | null;

  @Column('nvarchar', { name: 'oraCreazione', nullable: true, length: 8 })
  oraCreazione!: string | null;

  @Column('bigint', { name: 'utenteModifica', nullable: true })
  utenteModifica!: string | null;

  @Column('nvarchar', { name: 'dataModifica', nullable: true, length: 10 })
  dataModifica!: string | null;

  @Column('nvarchar', { name: 'oraModifica', nullable: true, length: 8 })
  oraModifica!: string | null;

  @Column('int', { name: 'attivaDiretta', nullable: true })
  attivaDiretta!: number | null;

  @Column('int', { name: 'attivaIndiretta', nullable: true })
  attivaIndiretta!: number | null;

  @Column('int', { name: 'anniAdesione', nullable: true })
  anniAdesione!: number | null;

  @Column('int', { name: 'gestionePreventivo', nullable: true })
  gestionePreventivo!: number | null;

  @Column('int', { name: 'interoNucleoFamiliare', nullable: true })
  interoNucleoFamiliare!: number | null;

  @Column('int', { name: 'escludeDocRimborsi', nullable: true })
  escludeDocRimborsi!: number | null;

  @Column('int', { name: 'struttureDirettaIncluse', nullable: true })
  struttureDirettaIncluse!: number | null;

  @Column('int', { name: 'struttureIndirettaIncluse', nullable: true })
  struttureIndirettaIncluse!: number | null;

  @Column('int', { name: 'categorieDirettaIncluse', nullable: true })
  categorieDirettaIncluse!: number | null;

  @Column('int', { name: 'categorieIndirettaIncluse', nullable: true })
  categorieIndirettaIncluse!: number | null;

  @Column('nvarchar', {
    name: 'descrizioneTesserino',
    nullable: true,
    length: 80,
  })
  descrizioneTesserino!: string | null;

  @Column('bigint', { name: 'codiceFdaOrigine', nullable: true })
  codiceFdaOrigine!: string | null;

  @Column('nvarchar', {
    name: 'dataInizioValidita',
    nullable: true,
    length: 10,
  })
  dataInizioValidita!: string | null;

  @Column('nvarchar', { name: 'dataFineValidita', nullable: true, length: 10 })
  dataFineValidita!: string | null;

  @Column('int', { name: 'limiteMassimoAssistenza', nullable: true })
  limiteMassimoAssistenza!: number | null;

  @Column('int', { name: 'limiteMinimoAssistenza', nullable: true })
  limiteMinimoAssistenza!: number | null;

  @Column('int', { name: 'limiteEtaAderentiDa', nullable: true })
  limiteEtaAderentiDa!: number | null;

  @Column('int', { name: 'limiteEtaFamiliariDa', nullable: true })
  limiteEtaFamiliariDa!: number | null;

  @Column('int', { name: 'limiteEtaAderentiA', nullable: true })
  limiteEtaAderentiA!: number | null;

  @Column('int', { name: 'limiteEtaFamiliariA', nullable: true })
  limiteEtaFamiliariA!: number | null;

  @Column('nvarchar', {
    name: 'descrizioneLettera',
    nullable: true,
    length: 80,
  })
  descrizioneLettera!: string | null;

  @Column('int', { name: 'fdaOpzionale', nullable: true })
  fdaOpzionale!: number | null;

  @Column('int', { name: 'giorniCarenzaTesserino', nullable: true })
  giorniCarenzaTesserino!: number | null;

  @Column('ntext', { name: 'informazioni', nullable: true })
  informazioni!: string | null;

  @Column('nvarchar', {
    name: 'denominazioneRegolamento',
    nullable: true,
    length: 1024,
    default: () => "''",
  })
  denominazioneRegolamento!: string | null;

  @Column('nvarchar', {
    name: 'dataMassimaAdesione',
    nullable: true,
    length: 10,
    default: () => "'9998-12-31'",
  })
  dataMassimaAdesione!: string | null;

  @Column('int', { name: 'prioritaWeb', default: () => '(0)' })
  prioritaWeb!: number;

  @Column('int', { name: 'attivaDirettaAreaRiservata', default: () => '(0)' })
  attivaDirettaAreaRiservata!: number;

  @OneToMany(
    () => SocioFormeAssistenzaEntity,
    (socioFormeAssistenzaEntity) => socioFormeAssistenzaEntity.formaAssistenza,
  )
  socioFormeAssistenza!: SocioFormeAssistenzaEntity[];

  constructor(init?: Partial<FormeAssistenzaEntity>) {
    Object.assign(this, init);
  }
}
