import { Column, Entity, Index, JoinColumn, ManyToOne } from 'typeorm';
import { ContrattoEntity } from './contratto.entity';
import { SocioEntity } from './socio.entity';

@Index(
  'PK_socioContratto',
  ['codiceSocio', 'codiceCapofamiglia', 'codiceContratto', 'dataInizio', 'dataFine', 'codiceFiguraContratto'],
  { unique: true },
)
@Entity('socioContratto')
export class SocioContrattoEntity {
  @Column('bigint', { primary: true, name: 'codiceSocio' })
  codiceSocio!: string;

  @Column('bigint', { primary: true, name: 'codiceCapofamiglia' })
  codiceCapofamiglia!: string;

  @Column('nvarchar', { primary: true, name: 'dataInizio', length: 10 })
  dataInizio!: string;

  @Column('nvarchar', { primary: true, name: 'dataFine', length: 10 })
  dataFine!: string;

  @Column('bigint', { primary: true, name: 'codiceContratto' })
  codiceContratto!: string;

  @Column('nvarchar', { name: 'contratto', length: 400 })
  nomeContratto!: string;

  @Column('bigint', { primary: true, name: 'codiceFiguraContratto' })
  codiceFiguraContratto!: string;

  @Column('nvarchar', { name: 'figuraContratto', length: 400 })
  figuraContratto!: string;

  @Column('nvarchar', { name: 'note', length: 400 })
  note!: string;

  @ManyToOne(() => SocioEntity, (socioEntity) => socioEntity.socioContratto)
  @JoinColumn([{ name: 'codiceSocio', referencedColumnName: 'codiceSocio' }])
  socio!: SocioEntity;

  @ManyToOne(() => ContrattoEntity, (contrattoEntity) => contrattoEntity.socioContratto)
  @JoinColumn([{ name: 'codiceContratto', referencedColumnName: 'codiceContratto' }])
  contratto!: ContrattoEntity;

  constructor(init?: Partial<SocioContrattoEntity>) {
    Object.assign(this, init);
  }
}
