import { Column, Entity, Index, JoinColumn, ManyToOne } from 'typeorm';
import { FormeAssistenzaEntity } from './formeAssistenza.entity';
import { SocioEntity } from './socio.entity';

@Index('PK_socioFormeAssistenza', ['codiceSocio', 'codiceFdA', 'dataInizio', 'dataFine', 'titolare'], { unique: true })
@Entity('socioFormeAssistenza')
export class SocioFormeAssistenzaEntity {
  @Column('bigint', { primary: true, name: 'codiceSocio' })
  codiceSocio!: string;

  @Column('bigint', { primary: true, name: 'codiceFdA' })
  codiceFdA!: string;

  @Column('nvarchar', { primary: true, name: 'dataInizio', length: 10 })
  dataInizio!: string;

  @Column('nvarchar', { primary: true, name: 'dataFine', length: 10 })
  dataFine!: string;

  @Column('int', { primary: true, name: 'titolare' })
  titolare!: number;

  @Column('bigint', { name: 'codiceContratto', nullable: true })
  codiceContratto!: string | null;

  @Column('bigint', { name: 'codiceFiguraContratto', nullable: true })
  codiceFiguraContratto!: string | null;

  @Column('int', { name: 'forzaEtaContributi', nullable: true })
  forzaEtaContributi!: number | null;

  @Column('nvarchar', { name: 'dataRicezione', nullable: true, length: 10 })
  dataRicezione!: string | null;

  @ManyToOne(() => FormeAssistenzaEntity, (formeAssistenzaEntity) => formeAssistenzaEntity.socioFormeAssistenza)
  @JoinColumn([{ name: 'codiceFdA', referencedColumnName: 'codiceFda' }])
  formaAssistenza!: FormeAssistenzaEntity;

  @ManyToOne(() => SocioEntity, (socioEntity) => socioEntity.socioFormeAssistenzas)
  @JoinColumn([{ name: 'codiceSocio', referencedColumnName: 'codiceSocio' }])
  socio!: SocioEntity;

  constructor(init?: Partial<SocioFormeAssistenzaEntity>) {
    Object.assign(this, init);
  }
}
