import { TypeOrmModuleOptions } from '@nestjs/typeorm';
import { SnakeNamingStrategy } from 'typeorm-naming-strategies';
import { DatabaseConfig } from './database-config';

export const typeormModuleOptionsFactory = async (
  databaseConfig: DatabaseConfig,
  entities: any[],
  name?: string,
): Promise<TypeOrmModuleOptions> => {
  return {
    name: name,
    type: databaseConfig.type as any,
    host: databaseConfig.host,
    port: databaseConfig.port,
    username: databaseConfig.username,
    password: databaseConfig.password,
    database: databaseConfig.database,
    entities: entities,
    synchronize: false,
    logging: process.env['NODE_ENV'] !== 'production',
    namingStrategy: new SnakeNamingStrategy(),
    options: {
      ...(!databaseConfig.secure ? { trustServerCertificate: true } : {}),
    },
  };
};
