// Based on https://github.com/rauschma/enumify
// Original license: MIT License - Copyright (c) 2020 Axel Rauschmayer

export const registeredEnums: Record<string, (typeof Enumify)[]> = {};
export function Enum(schema: string) {
  return function (target: typeof Enumify) {
    registeredEnums[schema] ??= [];
    registeredEnums[schema].push(target);
  };
}

export class Enumify {
  static enumKeys: Array<string>;
  static enumValues: Array<Enumify>;

  public readonly id?: number;
  public readonly nome?: string;

  static closeEnum() {
    const enumKeys: Array<string> = [];
    const enumValues: Array<Enumify> = [];

    for (const [key, value] of Object.entries(this)) {
      value.nome ??= key;
      value.id ??= enumValues.length;

      if (value.id == null || value.id === '') {
        throw new Error(`${this.name}.id`);
      }
      if (value.nome == null || value.nome === '') {
        throw new Error(`${this.name}.nome`);
      }

      enumKeys.push(value.nome);
      enumValues.push(value);
    }
    this.enumKeys = enumKeys;
    this.enumValues = enumValues;
  }

  static fromKey(key: string): undefined | Enumify {
    if (this.enumKeys == undefined) {
      throw new Error(`Did you forget to call static _ = ${this.name}.closeEnum() after setup?`);
    }

    const index = this.enumKeys.findIndex((enumKey) => enumKey.toUpperCase() === key.toString().toUpperCase());
    if (index >= 0) {
      return this.enumValues[index];
    }
    return undefined;
  }

  static fromValue(value: number): undefined | Enumify {
    if (this.enumValues == undefined) {
      throw new Error(`Did you forget to call static _ = ${this.name}.closeEnum() after setup?`);
    }

    const index = this.enumValues.map((x) => x.id).indexOf(value);
    if (index >= 0) {
      const key = this.enumKeys[index];
      return this.fromKey(key!);
    }
    return undefined;
  }

  protected constructor(id?: number, nome?: string) {
    this.id = id;
    this.nome = nome;
  }

  toString() {
    return `(${this.id}, ${this.nome})`;
  }
}
