import { Injectable, Logger, OnModuleInit } from '@nestjs/common';
import { FileTransaction } from './file-transaction';
import { createKeyv, Keyv } from '@keyv/redis';
import { parse, stringify } from 'flatted';
import { KeyvService } from '../keyv/keyv.service';

const FILE_TRANSACTIONS_KEY = `FILE_TRANSACTIONS_KEY`;

@Injectable()
export class FileTransactionsService implements OnModuleInit {
  private readonly logger = new Logger(FileTransactionsService.name);
  private readonly map: Record<string, FileTransaction> = {};

  private readonly keyv: Keyv;

  constructor(readonly keyvService: KeyvService) {
    this.keyv = this.keyvService.create({
      namespace: FileTransactionsService.name,
    });
  }

  register(logger?: Logger) {
    const tx = new FileTransaction(this, { logger });
    this.persist(tx);
    return tx;
  }

  persist(tx: FileTransaction) {
    this.map[tx.transactionId] = tx;
    this.keyv.set(FILE_TRANSACTIONS_KEY, this.map);
  }

  unregister(tx: FileTransaction) {
    delete this.map[tx.transactionId];
    this.keyv.set(FILE_TRANSACTIONS_KEY, this.map);
  }

  async onModuleInit() {
    this.logger.log('Checking for dangling file transactions...');
    const dangling = await this.keyv.get<Set<FileTransaction>>(FILE_TRANSACTIONS_KEY);

    if (dangling) {
      for (const danglingTx of Object.values(dangling)) {
        const tx = new FileTransaction(this, {
          ...danglingTx,
          logger: this.logger,
        });
        await tx.rollbackTransaction();
      }
    }
  }
}
